.. contents::

.. _node:

****
node
****
This module consists of an abstract parent class, ``Node``, and a number of child classes,
e.g. ``Facility``, ``Tank``, ``Pump``, ``Digestion``, etc.

.. automodule:: pype_schema.node
   :members:
